# OAuth Provider

A generic Python library to handle OAuth authentication for multiple providers like GitHub, Google, Microsoft, and LinkedIn.

## Features
- Supports multiple OAuth providers
- Handles token exchange and user info retrieval
- Easy configuration via environment variables